;
; 'ICC Anon'
;
; Released by C64 Crap Debunk in 2019
;
; c64crapdebunk.wordpress.com
; www.cosine.org.uk
;
; A simple intro written for the 
; Intro Creation Competition 2019
;
; Dedicated to all the old Compunetters!
;
; Code, graphics and music by aNdy/Cosine/C64CD
;
; Thanks to T.M.R/Cosine/C64CD
;
; This source is formatted for the ACME cross assembler
; which can be downloaded from...
; http://sourceforge.net/projects/acme-crossass/
;
; The final build was compressed and squished using
; Exomizer 2 which can be downloaded from...
; http://hem.bredband.net/magli143/exo/
;
; Questions about this code or about how the binaries
; were created can be asked by emailing aNdy...
; andy@cosine.org.uk
;
; Any spelling mistakes in the code comments below
; are the fault of someone else.  Honest...  ;)
;

; code begins... now! ============================

; the name and file format for the assembled program

		!to "c64cdanon.prg",cbm		; c64 format is useful, n'est-ce pas?

; drag in some charset, sprite and music binaries!	

		* = $0400					; the screen is assembled direct to $0400
		!binary "data/screen.raw"	; so doesn't have to be stored in code

		* = $1000
music	!binary "data/music.prg",,2

		* = $0800
		!binary "data/charset.chr"

		* = $2000
		!binary "data/sprites.spr"
		
; position of the raster interrupt(s) on-screen

raster_1_pos	= $00			; top border
raster_2_pos	= $32			; start of main screen
raster_3_pos	= $4c			; centre(ish) of screen with face
raster_4_pos	= $e1			; bottom section of screen
raster_5_pos	= $f9			; bottom border

; some label assignments (variables)

raster_num			= $50		; raster counter stores which split we are working in
sync				= $51		; interupt sync variable
scroll_x1			= $52		; title scroller screen position
scroll_pos1			= $53		; titles scroller position - $02 bytes used
scroll_x2			= $55		; title scroller screen position
scroll_pos2			= $56		; titles scroller position - $02 bytes used
fade_tmr			= $58		; sprite fade timer
fade_cnt			= $59		; sprite fade counter

; entry point for the code

		* = $2c00				

; stop interrupts, disable the roms and set up nmi and irq interrupt pointers		
				
code_entry

		sei						; disable maskable IRQs
		
		lda #$35				; kill EVERYTHING (MWHAHA!) except $f000-$ffff
		sta $01
		
; setup nmi

		lda #<nmi				; some nmi stuff
		sta $fffa
		lda #>nmi
		sta $fffb
		
; setup irq's

		lda #<int				; some irq stuff
		sta $fffe
		lda #>int
		sta $ffff

		lda #$7f
		sta $dc0d				; disable timer interrupts which can be generated by the two CIA chips
		sta $dd0d				; the kernal uses such an interrupt to flash the cursor and scan
								; the keyboard, so we better stop it

		lda $dc0d				; by reading this two registers we negate any pending CIA irqs.
		lda $dd0d				; if we don't do this, a pending CIA irq might occur after we
								; finish setting up our irq. we don't want that to happen.

		lda #raster_1_pos		; starting point of raster on screen ($00)
		sta $d012

		lda #$1b				; as there are more than 256 rasterlines, the topmost bit of $d011 serves as
		sta $d011				; the 9th bit for the rasterline we want our irq to be triggered.
		
		lda #$01
		sta $d019				; clear interupt bit
		sta $d01a				; tell vicii to generate interupt

		lda #$35				; turn off basic and kernal rom thus
		sta $01					; c64 now sees RAM everywhere except at $d000-$e000
		
		lda #$12				; use our custom font charset, ta very much!
		sta $d018

		cli

; first run screen setup =========================		
		
        lda #$00				; load 0 for black
		sta $d020				; store to background
        lda #$01				; load 1 for white		
		sta $d021				; store to background

; setup for the very first run by reading the data
; from the colour ram table and plonking it in memory

		ldx #$00				; zero x register
printcolram_loop				; load whatever is in the colour
		lda colour_ram,x		; ram table and write to the
		sta $d800,x				; colour ram
		lda colour_ram+250,x
		sta $d800+250,x	
		lda colour_ram+500,x
		sta $d800+500,x	
		lda colour_ram+750,x
		sta $d800+750,x	
		inx
		cpx #$fa				; done 250 writes?
		bne printcolram_loop	; all written? no? loop back!
				
; reset the message scroller for first run

		jsr scroll_reset1		; reset 'scroller' subroutine
		jsr scroll_reset2		; reset 'scroller' subroutine		
		
		lda #$50
		sta scroll_x1
		sta scroll_x2		

; prepare the music for first run		
		
		lda #$00				; setup the driver to
		jsr music+$00			; play the music
		
; set up raster handler for first raster at the top of the screen
		
		lda #$01
		sta raster_num
		
; set up some labels		
		
		lda #$00
		sta fade_tmr
		sta fade_cnt
		
; main loop code =========================================

mainloop
								; call these subroutines...
		jsr sync_wait			; wait until irq finishes!
		jsr write_message1		; write the scroller message top
		jsr write_message2		; write the scroller message bottom	
		
		lda $dc01				; load spacebar register
		cmp #$ef				; is space pressed?
		beq *+$05				; yes? jump down to reset the 64...

		jmp mainloop			; no? go back to 'mainloop' up by there
								; and call the subroutines again!
								
; space has been pressed so reset some registers

		sei
		lda #$37
		sta $01

		lda #$00
		sta $d011
		sta $d020
		sta $d021
		sta $d418

; reset the C64 (a linker could go here...)

		jmp $fce2								

										
; subroutines called from above code =====================		
		
; irq sync wait subroutine ---------------------------------- 
	   	 
sync_wait						; wait for sync update in irq code!
		lda #$00				; waits until the sync flag is
		sta sync				; set at the end of the interupt
sw_loop							; code further down.
		cmp sync				; no code in the main loop above
		beq sw_loop				; is executed until the interupt
								; has run it's course!
		rts
		
; update 'scrolling' message subroutine --------------------- 
		
write_message1
	
		ldx scroll_x1
		cpx #$20
		bcs scroll_cnt1

; fetch a character from the text table

scroll_read1

		ldy #$00
		lda (scroll_pos1),y
		bne scroll_write1
		
		jsr scroll_reset1
		
		jmp scroll_read1

; write that character to the screen
		
scroll_write1

		sta $0404,x

; update the text position

		inc scroll_pos1+$00
		bne *+$04
		inc scroll_pos1+$01

; store the current text position		
		
scroll_cnt1

		inx
		stx scroll_x1
		
		rts						; return to where this was called from

; reset the scroll message		
				
scroll_reset1

		lda #<greet_text1
		sta scroll_pos1+$00
		lda #>greet_text1
		sta scroll_pos1+$01
		
		rts						; return to where this was called from

				
write_message2
	
		ldx scroll_x2
		cpx #$20
		bcs scroll_cnt2

; fetch a character from the text table

scroll_read2

		ldy #$00
		lda (scroll_pos2),y
		bne scroll_write2
		
		jsr scroll_reset2
		
		jmp scroll_read2

; write that character to the screen
		
scroll_write2

		sta $07c4,x

; update the text position

		inc scroll_pos2+$00
		bne *+$04
		inc scroll_pos2+$01

; store the current text position		
		
scroll_cnt2

		inx
		stx scroll_x2
		
		rts						; return to where this was called from

; reset the scroll message		
				
scroll_reset2

		lda #<greet_text2
		sta scroll_pos2+$00
		lda #>greet_text2
		sta scroll_pos2+$01
		
		rts						; return to where this was called from		
		
; end subroutines =====================================		
			

; IRQ interrupt code =================================

int
		pha  
		txa
		pha
		tya
		pha
		
		lda $d019
		and #$01
		sta $d019
		bne intr_trigd
		
		jmp irq_exit			; no interupt triggered? exit irq code!
		
; an interrupt has triggered!?!
; which split should we run? let's check...

intr_trigd

		lda raster_num			; load up the raster_num variable
		
		cmp #$02				; is it set to '2'?
		bne *+$05				; no? then jump down to check for '3'
		jmp irq_rout2			; yes? jump down to irq_rout2!

		cmp #$03				; is the raster_num set to '3'?
		bne *+$05				; no? jump down and run irq_rout1!
		jmp irq_rout3			; yes? jump down to irq_rout3!

		cmp #$04				; is the raster_num set to '4'?
		bne *+$05				; no? jump down and run irq_rout1!
		jmp irq_rout4			; yes? jump down to irq_rout4!
		
		cmp #$05				; is the raster_num set to '5'?
		bne *+$05				; no? jump down and run irq_rout1!
		jmp irq_rout5			; yes? jump down to irq_rout5!

; raster split 1 code -------------------------------

irq_rout1						; top section of the screen

; set interrupt handler ready for split 2

		lda #$02
		sta raster_num
		lda #raster_2_pos
		sta $d012
		
; black border/background in this split please!		
		
		lda #$00
		sta $d020
		sta $d021		

; split 1 is done, exit irq interrupt		
					
		jmp irq_exit			; now exit the interupt!
		
; raster split 2 code ------------------------------------

irq_rout2

; set interrupt handler ready for split 3
	
		lda #$03
		sta raster_num
		lda #raster_3_pos
		sta $d012

; make the background white for the PETSCII face forehead	
		
		lda #$01
		sta $d021		
		
; call music player	and play dat choon!
		
		jsr music+$03			; play tune!		
		
; split 2 is done, exit irq interrupt

		jmp irq_exit		
		
; raster split 3 code ------------------------------------

irq_rout3

; set interrupt handler ready for split 4
	
		lda #$04
		sta raster_num
		lda #raster_4_pos
		sta $d012

; white borders in this split please!
	
		lda #$01
		sta $d020
		
; draw the sprites to the left of the face	
		
		lda #$1f				; turn on..
		sta $d015				; 5 sprites!

		lda #$00				; make these sprites
		sta $d01c				; hires
		sta $d01b
		sta $d01d				; unexpand all sprites 
		sta $d017				; horizontally & vertically		

		ldx #$00
		ldy #$00
draw_sprites_c					; lets draw the sprites
		lda c_sprite_x,x		; load in the x pos from the table
		sta $d000,y				; store in the sprites x register
		lda c_sprite_y,x		; pull in y positions
		sta $d001,y				; store in the sprites y registers
		lda c_sprite_col		; pull in sprite colour
		sta $d027,x				; and store in the colour registers
		lda c_sprite_def,x		; pull in sprite definitions
		sta $07f8,x				; and throw them into memory
		iny
		iny
		inx
		cpx #$05				; all 5 done?
		bne draw_sprites_c		; no? get back up there and do more!
		
; now let's fade the central logo sprites through shades of grey!

		ldx fade_tmr			; load whatever is in the fade timer
		inx						; increase it!
		cpx #$05				; is it 5?
		bne fade_skip			; nope? skip the fade routine then!
		
		ldy fade_cnt			; load y register with fade_cnt
		lda c_sprite_fade,y		; what's at position y in the fade table?
		sta c_sprite_col		; load whatever it is into c_sprite_col
		lda fade_cnt			; load accum with fade_cnt
		inc fade_cnt			; increase it by 1
		cmp #$08				; is it equal to 8?
		bne reset_tmr			; no? go down to reset the timer
								; yes?
		lda #$00				; lets reset the fade_cnt
		sta fade_cnt			; with 0 to wrap the fade table
reset_tmr
		ldx #$00				; reset the timer to 0!	
fade_skip
		stx fade_tmr			; store x register to the fade timer			

; split 3 is done, exit irq interrupt

		jmp irq_exit			

; raster split 4 code ------------------------------------

irq_rout4

; set interrupt handler ready for split 5		

		lda #$05
		sta raster_num
		lda #raster_5_pos
		sta $d012	

; back to black borders in this split please!		
		
		lda #$00
		sta $d020

; draw the sprites in the upper/lower borders		
		
		lda #$ff				; turn on..
		sta $d015				; all 8 sprites!

		sta $d01d				; expand all sprites 
		sta $d017				; horizontally & vertically

		lda #$00				; make these sprites
		sta $d01c				; hires
		sta $d01b
		
		lda #$80				; sprites 7 & 8 
		sta $d010				; are in the MSB!

		ldx #$00
		ldy #$00
draw_sprites_b					; lets draw the sprites
		lda b_sprite_x,x		; load in the x pos from the table
		sta $d000,y				; store in the sprites x register
		lda b_sprite_y,x		; pull in y positions
		sta $d001,y				; store in the sprites y registers
		lda b_sprite_col,x		; pull in sprite colours
		sta $d027,x				; and store in the colour registers
		lda b_sprite_def,x		; pull in sprite definitions
		sta $07f8,x				; and throw them into memory
		iny
		iny
		inx
		cpx #$08				; all 8 done?
		bne draw_sprites_b		; no? get back up there and do more!
		
; split 4 is done, exit irq interrupt

		jmp irq_exit

		
; raster split 5 code ------------------------------------

irq_rout5

; set interrupt handler ready for split 1

		lda #$01
		sta raster_num
		lda #raster_1_pos
		sta $d012

; make the background black again

		lda #$00
		sta $d021	
		
; open the top and bottom borders		
				
		lda #$14
		sta $d011

		lda #$fc
		cmp $d012
		bne *-$03

		lda #$1b
		sta $d011
			
; set sync variable for main line code synchronisation

set_sync
		lda #$01				; set the sync flag to '1'		
		sta sync				; so the main code runs!
		
; restore registers and exit irq interrupt

irq_exit

		pla
		tay
		pla
		tax
		pla
nmi		rti

; end irq interrupt code =============================


; all data tables live here! ===============================
		
; sprite table for the border (b) sprites

b_sprite_x		!byte $88,$b8,$38,$68,$98,$c8,$f8,$08
b_sprite_y		!byte $fb,$fb,$00,$00,$00,$00,$00,$00
b_sprite_def	!byte $86,$87,$80,$80,$80,$80,$80,$80
b_sprite_col	!byte $00,$00,$01,$01,$01,$01,$01,$01

; sprite table for the centre (c) screen sprites next to face

c_sprite_x		!byte $3a,$3a,$3a,$3a,$3a
c_sprite_y		!byte $52,$6f,$8c,$a9,$c6
c_sprite_def	!byte $81,$82,$83,$81,$85
c_sprite_col	!byte $00
c_sprite_fade	!byte $00,$0b,$0c,$0f,$01,$0f,$0c,$0b

; colour ram table for the screen

colour_ram
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$01,$00,$00,$00,$00,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$00,$00,$00,$01,$00,$00,$00,$0F,$00,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$01,$01,$01,$01,$01,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$01,$01,$01,$01,$01,$00,$00,$00,$00,$00,$00,$0F,$0F,$00,$00,$00,$0F,$00,$00,$0F,$00,$00,$00,$0F,$0F,$00,$00,$00,$00,$00,$01,$01,$01,$01,$01,$01,$01,$00
!byte $00,$00,$01,$00,$01,$01,$01,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$01,$01,$01,$01,$01,$01,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$00,$01,$01,$01,$01,$01,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$00,$00,$00,$0F,$00,$0F,$0F,$0F,$0F,$0F,$00,$00,$00,$00,$0F,$0F,$0F,$0F,$0F,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$00,$01,$01,$00,$00,$00,$0A,$0A,$0A,$0A,$00,$00,$0F,$00,$00,$00,$00,$0F,$00,$00,$0A,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$00,$00,$00,$0A,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$00,$00,$00,$0A,$0A,$0A,$0A,$0F,$0F,$00,$00,$00,$00,$00,$00,$0F,$0F,$0A,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$00,$01,$01,$00,$00,$00,$00,$00,$00,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$00,$00,$00,$0F,$00,$00,$0F,$0F,$0F,$00,$00,$0F,$0F,$00,$00,$0F,$0F,$0F,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$00,$00,$01,$00,$00,$01,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$01,$00,$00,$0F,$0F,$0A,$00,$00,$00,$00,$00,$0F,$0F,$00,$00,$00,$00,$00,$0A,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$0F,$0A,$0A,$0A,$0A,$0F,$0F,$0F,$0F,$0F,$0F,$0A,$0A,$0A,$0A,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$00,$00,$00,$00,$00,$0F,$0F,$0F,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$0F,$0F,$0F,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$00,$00,$01,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$01,$01,$01,$00,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$0F,$00,$00,$0F,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$0F,$00,$00,$0F,$0F,$0F,$00,$00,$00,$02,$02,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$0F,$02,$02,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

; text data for both rolling messages

greet_text1
		!scr "c64cd presents, for the icc 2019"
		!scr "a 16k intro called... 'icc anon'"
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr "   code, graphix and musix by   "
		!scr "      >>   &  n  =  %   <<      "
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr "a slap on the back and thanks to"
		!scr "     t.m.r / cosine / c64cd     "
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr " thanks also to motion/artstate "
		!scr " for continued positive support "
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr " special greetings are sent out "
		!scr "to these > important < people..."
		!scr "  * moloch/triad * warlock/al * "
		!scr "  *  redback/al  *  w0rm/al  *  "
		!scr "...and huge comedy hand waves to"
		!scr "* trooper  *  aumtron  *  fuzz *"
		!scr "- ---+---+-+-+----+-+-+---+--- -"							
		!scr "nothing amazing here,  just &n=%"
		!scr " paying homage to the wonderful "
		!scr "  compunet demos of the 1980's  "
		!scr " with this little tribute while "	
		!scr "  continuing to experiment in   "
		!scr " the delightful world of 6502!  "
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr "the music is called 'tiny boner'"
		!scr "  because it is a reworked and  "
		!scr "  and slightly remixed excerpt  "
		!scr " of a larger mod called 'boner' "
		!scr "composed by  marx marvelous/tppi"
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr "on this very rare occasion, &n=%"
		!scr "has used a *> 6581 <* along with"
		!scr " some simple, unfiltered sounds "
		!scr "for (hopefully) an 80's sounding" 
		!scr "  sound interface device tune!  "
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr "   special thanks to didi for   "
		!scr "  organising the competition!!  "
		!scr "- ---+---+-+-+----+-+-+---+--- -"		 
		!scr "  please visit the c64cd whq:   "
		!scr "  c64crapdebunk.wordpress.com   "
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr "&n=% signing off in december '19"
		!scr "- ---+---+-+-+----+-+-+---+--- -"					 			
						
		!byte $00		; end of text marker
		
greet_text2
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr " c64cd sends out cordial greets "
		!scr " to the following people/groups "
		!scr "- ---+---+-+-+----+-+-+---+--- -"
		!scr "  * 1001 crew * ash and dave *  "
		!scr "         * black  bag *         "
		!scr "   * borderzone dezign team *   "
		!scr "   * copy service stuttgart *   "
		!scr "    * dynamic duo * excess *    "
		!scr " four horsemen of the apocalypse"
		!scr "      * happy  demomaker *      "
		!scr "   * harlow cracking service *  "
		!scr "   * high-tech team * ikari *   "
		!scr "  * jewels * kernal * laxity *  "
		!scr "         * mean  team *         "
		!scr "   * paul, shandor and matt *   "
		!scr "     * pulse  productions *     "
		!scr "   * reset 86 * rob hubbard *   "
		!scr "     * scoop * slipstream *     "
		!scr "   * stoat and tim * tangent *  "
		!scr "  * thalamus * the commandos *  "
		!scr "   * the gps * the six pack *   "
		!scr "   * we  music * xess * yak *   "
		!scr "       * yeti factories *       "
		!scr " and the usual anti-greeting to "
		!scr "      that there c64hater!      "							

		!byte $00		; end of text marker			
				
	
; end of code!!! ========================================================================
